@@ -10,7 +10,7 @@ class Config_DjangoWhitenoise(object):
     """
     # enable for persisent file and gzip support
     BASE_DIR = os.path.dirname(os.path.abspath(__file__)) + '/../'
-    STATIC_ROOT = os.path.join(BASE_DIR, 'staticfiles')
+    STATIC_ROOT = os.path.abspath(os.path.join(BASE_DIR, 'staticfiles'))
     STATICFILES_STORAGE = 'whitenoise.storage.CompressedManifestStaticFilesStorage'
     if os.environ.get('DJANGO_STATIC'):
         STATICFILES_STORAGE = 'django.contrib.staticfiles.storage.CachedStaticFilesStorage'
