@@ -12,7 +12,6 @@ import warnings
 from importlib import import_module
 
 from ordered_set import OrderedSet
-from six import string_types, iteritems
 
 from .crypto import AESCipher
 
@@ -59,10 +58,11 @@ class EnvSettingsBase(object):
 
     @classmethod
     def setup(cls, globalsobj, env_class=None, config_mod=None,
-              silent=False, use_lowercase=False):
+              verbose=False, use_lowercase=False):
         config_mod = config_mod or ("config",)
         cls.password, cls.aes = password()
-        if isinstance(env_class, string_types):
+        cls.verbose = verbose
+        if isinstance(env_class, str):
             if '.' in env_class:
                 config_mod = env_class.split('.')[:-1]
                 env_class = env_class.split('.')[-1]
@@ -124,6 +124,12 @@ class EnvSettingsBase(object):
         if cls.verbose:
             print(text)
 
+    @classmethod
+    def debug(cls, text):
+        logger.debug(text)
+        if cls.verbose:
+            print(text)
+
     @classmethod
     def warn(cls, text):
         logger.warn(text)
@@ -148,7 +154,7 @@ class EnvSettingsBase(object):
         """
         cls._allow_keys_patch = keys.pop('ALLOW_KEYS_PATCH',
                                          cls._allow_keys_patch)
-        if isinstance(cls._allow_keys_patch, string_types):
+        if isinstance(cls._allow_keys_patch, str):
             cls._allow_keys_patch = cls._allow_keys_patch.split(',')
         if isinstance(keys, dict):
             globalsobj.update(keys)
@@ -208,7 +214,7 @@ class EnvSettingsBase(object):
         settings parameters in the globals object.
         """
         mod = None
-        if isinstance(env_class, string_types):
+        if isinstance(env_class, str):
             try:
                 logger.debug("Trying to load %s from %s" %
                              (env_class, config_mod))
@@ -216,7 +222,7 @@ class EnvSettingsBase(object):
                 settings_cls = getattr(mod, env_class)
             except BaseException as e:
                 cls.fail('[ERROR] Trying to load %s (%s), Exception was: %s' %
-                         (env_class, mod, e))
+                         (env_class, mod, repr(e)))
                 if '--traceback' in sys.argv:
                     from traceback import print_exc
                     print_exc()
@@ -233,7 +239,9 @@ class EnvSettingsBase(object):
                 cls._config_modules.append(base_cls.__module__)
                 for var in base_cls.__dict__:
                     if use_lowercase or isuppercase(var):
-                        logger.debug("Setting %s from %s" % (var, base_cls))
+                        cls.debug("Setting %s from %s" % (var, base_cls))
+                        if var in globalsobj:
+                           cls.debug("Setting %s from %s was already defined" % (var, base_cls))
                         globalsobj[var] = base_cls.__dict__[var]
                 # register patches
                 patches = base_cls.__dict__.get('__patches__', ())
@@ -310,7 +318,7 @@ class EnvSettingsBase(object):
         convenience function to patch the middleware classes
         """
         addl = make_tuple(addl)
-        return cls.patch_list('MIDDLEWARE_CLASSES', addl, prepend=prepend,
+        return cls.patch_list('MIDDLEWARE', addl, prepend=prepend,
                               remove=remove, at=at)
 
     @classmethod
@@ -351,7 +359,7 @@ class EnvSettingsBase(object):
     def report(cls, globalsobj, keys=None):
         keys = make_tuple(keys)
         print('-- SETTINGS as seen by EnvSettingsBase --\n')
-        for k, v in iteritems(globalsobj):
+        for k, v in globalsobj.items():
             if not keys or k in keys:
                 print("%s=%s\n" % (k, v))
 
@@ -539,7 +547,7 @@ class StackableSettings(EnvSettingsBase):
     @classmethod
     def should_debug(cls, clean_args=True):
         in_argv = '--debug-config' in sys.argv
-        in_env = os.environ.get('APP_CONFIG_DEBUG')
+        in_env = os.environ.get('APP_CONFIG_DEBUG', '0') in ('1', 'yes', 'true')
         should = in_argv or in_env
         if clean_args and in_argv:
             index = sys.argv.index('--debug-config')
@@ -556,7 +564,9 @@ class StackableSettings(EnvSettingsBase):
         envcls = cls.ENV_LOCAL_TEST if cls.is_test_run() else cls.ENV_LOCAL
         config = os.environ.get(conf_var, envcls)
         globalsobj = globalsobj or sys._getframe(1).f_globals
-        EnvSettingsBase.setup(globalsobj, env_class=config, config_mod=config_mod)
+        EnvSettingsBase.setup(globalsobj, env_class=config, config_mod=config_mod,
+                              verbose=cls.should_debug())
+
 
     @classmethod
     def root_path(cls, filename=None):
@@ -658,9 +668,8 @@ if test_configvar != use_configvar and test_configvar in os.environ:
     warnings.warn('Use of {test_configvar} is deprecated. Use {use_configvar} instead.'.format(**locals()))
 
 # auto load DjangoStackableSettings if Django is installed  -- backwards compatibility
-# -- we don't try to import django because this will mess with settings before we had a chance to
-import six
-django_path = os.path.join(os.path.dirname(six.__file__), 'django')
+# -- we don't try to import django because this will mess with settings before we had a chance to load
+django_path = os.path.join(os.path.dirname(__file__), 'django')
 if os.path.exists(django_path):
     StackableSettings = DjangoStackableSettings
 
